@@ -1,6 +1,511 @@
 """KISAO ontology."""
 
 from enum import Enum
+from typing import Optional, Union
+
+
+KISAOType = Union[str, "KISAO"]
+
+_terms = {
+    "KISAO_0000000": "modelling and simulation algorithm",
+    "KISAO_0000003": "weighted stochastic simulation algorithm",
+    "KISAO_0000015": "Gillespie first reaction algorithm",
+    "KISAO_0000017": "multi-state agent-based simulation method",
+    "KISAO_0000019": "CVODE",
+    "KISAO_0000020": "PVODE",
+    "KISAO_0000021": "StochSim nearest-neighbour algorithm",
+    "KISAO_0000022": "Elf and Ehrenberg method",
+    "KISAO_0000027": "Gibson-Bruck next reaction algorithm",
+    "KISAO_0000028": "slow-scale stochastic simulation algorithm",
+    "KISAO_0000029": "Gillespie direct algorithm",
+    "KISAO_0000030": "Euler forward method",
+    "KISAO_0000031": "Euler backward method",
+    "KISAO_0000032": "explicit fourth-order Runge-Kutta method",
+    "KISAO_0000033": "Rosenbrock method",
+    "KISAO_0000038": "sorting stochastic simulation algorithm",
+    "KISAO_0000039": "tau-leaping method",
+    "KISAO_0000040": "Poisson tau-leaping method",
+    "KISAO_0000045": "implicit tau-leaping method",
+    "KISAO_0000046": "trapezoidal tau-leaping method",
+    "KISAO_0000048": "adaptive explicit-implicit tau-leaping method",
+    "KISAO_0000051": "Bortz-Kalos-Lebowitz algorithm",
+    "KISAO_0000056": "Smoluchowski equation based method",
+    "KISAO_0000057": "Brownian diffusion Smoluchowski method",
+    "KISAO_0000058": "Greens function reaction dynamics",
+    "KISAO_0000064": "Runge-Kutta based method",
+    "KISAO_0000068": "deterministic cellular automata update algorithm",
+    "KISAO_0000071": "LSODE",
+    "KISAO_0000074": "binomial tau-leaping method",
+    "KISAO_0000075": "Gillespie multi-particle method",
+    "KISAO_0000076": "Stundzia and Lumsden method",
+    "KISAO_0000081": "estimated midpoint tau-leaping method",
+    "KISAO_0000082": "k-alpha leaping method",
+    "KISAO_0000084": "nonnegative Poisson tau-leaping method",
+    "KISAO_0000086": "Fehlberg method",
+    "KISAO_0000087": "Dormand-Prince method",
+    "KISAO_0000088": "LSODA",
+    "KISAO_0000089": "LSODAR",
+    "KISAO_0000090": "LSODI",
+    "KISAO_0000091": "LSODIS",
+    "KISAO_0000093": "LSODPK",
+    "KISAO_0000094": "Livermore solver",
+    "KISAO_0000095": "sub-volume stochastic reaction-diffusion algorithm",
+    "KISAO_0000097": "modelling and simulation algorithm characteristic",
+    "KISAO_0000098": "type of variable",
+    "KISAO_0000099": "type of system behaviour",
+    "KISAO_0000100": "type of progression time step",
+    "KISAO_0000102": "spatial description",
+    "KISAO_0000103": "deterministic system behaviour",
+    "KISAO_0000104": "stochastic system behaviour",
+    "KISAO_0000105": "discrete variable",
+    "KISAO_0000106": "continuous variable",
+    "KISAO_0000107": "progression with adaptive time step",
+    "KISAO_0000108": "progression with fixed time step",
+    "KISAO_0000201": "modelling and simulation algorithm parameter",
+    "KISAO_0000203": "particle number lower limit",
+    "KISAO_0000204": "particle number upper limit",
+    "KISAO_0000205": "partitioning interval",
+    "KISAO_0000209": "relative tolerance",
+    "KISAO_0000211": "absolute tolerance",
+    "KISAO_0000216": "use reduced model",
+    "KISAO_0000219": "maximum Adams order",
+    "KISAO_0000220": "maximum BDF order",
+    "KISAO_0000223": "number of history bins",
+    "KISAO_0000228": "tau-leaping epsilon",
+    "KISAO_0000230": "minimum reactions per leap",
+    "KISAO_0000231": "Pahle hybrid method",
+    "KISAO_0000232": "LSOIBT",
+    "KISAO_0000233": "LSODES",
+    "KISAO_0000234": "LSODKR",
+    "KISAO_0000235": "type of solution",
+    "KISAO_0000236": "exact solution",
+    "KISAO_0000237": "approximate solution",
+    "KISAO_0000238": "type of method",
+    "KISAO_0000239": "explicit method type",
+    "KISAO_0000240": "implicit method type",
+    "KISAO_0000241": "Gillespie-like method",
+    "KISAO_0000242": "error control parameter",
+    "KISAO_0000243": "method switching control parameter",
+    "KISAO_0000244": "granularity control parameter",
+    "KISAO_0000245": "has characteristic",
+    "KISAO_0000246": "is hybrid of",
+    "KISAO_0000248": "tau-leaping delta",
+    "KISAO_0000249": "critical firing threshold",
+    "KISAO_0000250": "is parameter of",
+    "KISAO_0000252": "partitioning control parameter",
+    "KISAO_0000253": "coarse-graining factor",
+    "KISAO_0000254": "Brownian diffusion accuracy",
+    "KISAO_0000255": "molecules per virtual box",
+    "KISAO_0000256": "virtual box side length",
+    "KISAO_0000257": "surface-bound epsilon",
+    "KISAO_0000258": "neighbour distance",
+    "KISAO_0000259": "has parameter",
+    "KISAO_0000260": "virtual box size",
+    "KISAO_0000261": "Euler method",
+    "KISAO_0000263": "NFSim agent-based simulation method",
+    "KISAO_0000264": "cellular automata update method",
+    "KISAO_0000268": "is characteristic of",
+    "KISAO_0000273": "hard-particle molecular dynamics",
+    "KISAO_0000274": "first-passage Monte Carlo algorithm",
+    "KISAO_0000276": "Gill method",
+    "KISAO_0000278": "Metropolis Monte Carlo algorithm",
+    "KISAO_0000279": "Adams-Bashforth method",
+    "KISAO_0000280": "Adams-Moulton method",
+    "KISAO_0000281": "multistep method",
+    "KISAO_0000282": "KINSOL",
+    "KISAO_0000283": "IDA",
+    "KISAO_0000285": "finite volume method",
+    "KISAO_0000286": "Euler-Maruyama method",
+    "KISAO_0000287": "Milstein method",
+    "KISAO_0000288": "backward differentiation formula",
+    "KISAO_0000289": "Adams method",
+    "KISAO_0000290": "Merson method",
+    "KISAO_0000296": "Hammer-Hollingsworth method",
+    "KISAO_0000297": "Lobatto method",
+    "KISAO_0000299": "Butcher-Kuntzmann method",
+    "KISAO_0000301": "Heun method",
+    "KISAO_0000302": "embedded Runge-Kutta method",
+    "KISAO_0000303": "Zonneveld method",
+    "KISAO_0000304": "Radau method",
+    "KISAO_0000305": "Verner method",
+    "KISAO_0000306": "Lagrangian sliding fluid element algorithm",
+    "KISAO_0000307": "finite difference method",
+    "KISAO_0000308": "MacCormack method",
+    "KISAO_0000309": "Crank-Nicolson method",
+    "KISAO_0000310": "method of lines",
+    "KISAO_0000311": "type of domain geometry handling",
+    "KISAO_0000314": "S-System power-law canonical differential equations solver",
+    "KISAO_0000315": "lattice gas automata",
+    "KISAO_0000316": "enhanced Greens function reaction dynamics",
+    "KISAO_0000317": "E-Cell multi-algorithm simulation method",
+    "KISAO_0000318": "Gauss-Legendre Runge-Kutta method",
+    "KISAO_0000319": "Monte Carlo method",
+    "KISAO_0000320": "BioRica hybrid method",
+    "KISAO_0000321": "Cash-Karp method",
+    "KISAO_0000322": "hybridity",
+    "KISAO_0000323": "equation-free probabilistic steady-state approximation",
+    "KISAO_0000324": "nested stochastic simulation algorithm",
+    "KISAO_0000325": "minimum fast/discrete reaction occurrences number",
+    "KISAO_0000326": "number of samples",
+    "KISAO_0000327": "maximum discrete number",
+    "KISAO_0000328": "minimum fast rate",
+    "KISAO_0000329": "constant-time kinetic Monte Carlo algorithm",
+    "KISAO_0000330": "R-leaping algorithm",
+    "KISAO_0000331": "exact R-leaping algorithm",
+    "KISAO_0000332": "ER-leap initial leap",
+    "KISAO_0000333": "accelerated stochastic simulation algorithm",
+    "KISAO_0000334": "multiparticle lattice gas automata",
+    "KISAO_0000335": "generalized stochastic simulation algorithm",
+    "KISAO_0000336": "D-leaping method",
+    "KISAO_0000337": "finite element method",
+    "KISAO_0000338": "h-version of the finite element method",
+    "KISAO_0000339": "p-version of the finite element method",
+    "KISAO_0000340": "h-p version of the finite element method",
+    "KISAO_0000341": "mixed finite element method",
+    "KISAO_0000342": "level set method",
+    "KISAO_0000343": "generalized finite element method",
+    "KISAO_0000345": "h-p cloud method",
+    "KISAO_0000346": "mesh-based geometry handling",
+    "KISAO_0000347": "meshless geometry handling",
+    "KISAO_0000348": "extended finite element method",
+    "KISAO_0000349": "method of finite spheres",
+    "KISAO_0000350": "probability-weighted dynamic Monte Carlo method",
+    "KISAO_0000351": "multinomial tau-leaping method",
+    "KISAO_0000352": "hybrid method",
+    "KISAO_0000353": "generalized minimal residual algorithm",
+    "KISAO_0000354": "Krylov subspace projection method",
+    "KISAO_0000355": "DASPK",
+    "KISAO_0000356": "DASSL",
+    "KISAO_0000357": "conjugate gradient method",
+    "KISAO_0000358": "biconjugate gradient method",
+    "KISAO_0000359": "is similar to",
+    "KISAO_0000360": "uses",
+    "KISAO_0000361": "is generalization of",
+    "KISAO_0000362": "implicit-state Doob-Gillespie algorithm",
+    "KISAO_0000363": "rule-based simulation method",
+    "KISAO_0000364": "Adams predictor-corrector method",
+    "KISAO_0000365": "NDSolve method",
+    "KISAO_0000366": "symplecticness",
+    "KISAO_0000367": "partitioned Runge-Kutta method",
+    "KISAO_0000369": "partial differential equation discretization method",
+    "KISAO_0000370": "type of problem",
+    "KISAO_0000371": "stochastic differential equation problem",
+    "KISAO_0000372": "partial differential equation problem",
+    "KISAO_0000373": "differential-algebraic equation problem",
+    "KISAO_0000374": "ordinary differential equation problem",
+    "KISAO_0000375": "delay differential equation problem",
+    "KISAO_0000376": "linearity of equation",
+    "KISAO_0000377": "one-step method",
+    "KISAO_0000378": "implicit midpoint rule",
+    "KISAO_0000379": "Bulirsch-Stoer algorithm",
+    "KISAO_0000380": "Richardson extrapolation based method",
+    "KISAO_0000381": "midpoint method",
+    "KISAO_0000382": "modified midpoint method",
+    "KISAO_0000383": "Bader-Deuflhard method",
+    "KISAO_0000384": "semi-implicit midpoint rule",
+    "KISAO_0000386": "scaled preconditioned generalized minimal residual method",
+    "KISAO_0000388": "minimal residual method",
+    "KISAO_0000389": "quasi-minimal residual method",
+    "KISAO_0000392": "biconjugate gradient stabilized method",
+    "KISAO_0000393": "ingenious conjugate gradients-squared method",
+    "KISAO_0000394": "quasi-minimal residual variant of biconjugate gradient stabilized method",
+    "KISAO_0000395": "improved biconjugate gradient method",
+    "KISAO_0000396": "transpose-free quasi-minimal residual algorithm",
+    "KISAO_0000397": "preconditioning technique",
+    "KISAO_0000398": "iterative method for solving a system of linear equations",
+    "KISAO_0000399": "is used by",
+    "KISAO_0000403": "homogeneousness of equation",
+    "KISAO_0000404": "symmetricity of matrix",
+    "KISAO_0000405": "type of differential equation",
+    "KISAO_0000407": "steady state method",
+    "KISAO_0000408": "Newton-type method",
+    "KISAO_0000409": "ordinary Newton method",
+    "KISAO_0000410": "simlified Newton method",
+    "KISAO_0000411": "Newton-like method",
+    "KISAO_0000412": "inexact Newton method",
+    "KISAO_0000413": "exact Newton method",
+    "KISAO_0000415": "maximum number of steps",
+    "KISAO_0000416": "partial least squares regression method",
+    "KISAO_0000417": "hierarchical cluster-based partial least squares regression method",
+    "KISAO_0000418": "N-way partial least squares regression method",
+    "KISAO_0000419": "metamodelling method",
+    "KISAO_0000420": "number of partial least squares components",
+    "KISAO_0000421": "type of validation",
+    "KISAO_0000422": "number of N-way partial least squares regression factors",
+    "KISAO_0000423": "partial least squares regression-like method",
+    "KISAO_0000424": "mean-centring of variables",
+    "KISAO_0000425": "standardising of variables",
+    "KISAO_0000427": "number of clusters",
+    "KISAO_0000428": "matrix for clusterization",
+    "KISAO_0000429": "clusterization parameter",
+    "KISAO_0000430": "variables preprocessing parameter",
+    "KISAO_0000432": "IDA-like method",
+    "KISAO_0000433": "CVODE-like method",
+    "KISAO_0000434": "Higham-Hall method",
+    "KISAO_0000435": "embedded Runge-Kutta 5(4) method",
+    "KISAO_0000436": "Dormand-Prince 8(5,3) method",
+    "KISAO_0000437": "flux balance analysis",
+    "KISAO_0000447": "COAST",
+    "KISAO_0000448": "logical model simulation method",
+    "KISAO_0000449": "synchronous logical model simulation method",
+    "KISAO_0000450": "asynchronous logical model simulation method",
+    "KISAO_0000451": "type of updating policy",
+    "KISAO_0000452": "random updating policy",
+    "KISAO_0000453": "ordered updating policy",
+    "KISAO_0000454": "constant updating policy",
+    "KISAO_0000455": "prioritized updating policy",
+    "KISAO_0000467": "maximum step size",
+    "KISAO_0000468": "maximal timestep method",
+    "KISAO_0000469": "maximal timestep",
+    "KISAO_0000470": "optimization algorithm",
+    "KISAO_0000471": "local optimization algorithm",
+    "KISAO_0000472": "global optimization algorithm",
+    "KISAO_0000473": "Bayesian inference algorithm",
+    "KISAO_0000475": "integration method",
+    "KISAO_0000476": "iteration type",
+    "KISAO_0000477": "linear solver",
+    "KISAO_0000478": "preconditioner",
+    "KISAO_0000479": "upper half-bandwidth",
+    "KISAO_0000480": "lower half-bandwidth",
+    "KISAO_0000481": "interpolate solution",
+    "KISAO_0000482": "half-bandwith parameter",
+    "KISAO_0000483": "step size",
+    "KISAO_0000484": "maximum order",
+    "KISAO_0000485": "minimum step size",
+    "KISAO_0000486": "maximum iterations",
+    "KISAO_0000487": "minimum damping",
+    "KISAO_0000488": "seed",
+    "KISAO_0000491": "discrete event simulation algorithm",
+    "KISAO_0000492": "asynchronous updating policy",
+    "KISAO_0000493": "synchronous updating policy",
+    "KISAO_0000494": "fully asynchronous updating policy",
+    "KISAO_0000495": "random asynchronous updating policy",
+    "KISAO_0000496": "CVODES",
+    "KISAO_0000497": "KLU",
+    "KISAO_0000498": "number of runs",
+    "KISAO_0000499": "dynamic flux balance analysis",
+    "KISAO_0000500": "SOA-DFBA",
+    "KISAO_0000501": "DOA-DFBA",
+    "KISAO_0000502": "DA-DFBA",
+    "KISAO_0000503": "simulated annealing",
+    "KISAO_0000504": "random search",
+    "KISAO_0000505": "particle swarm",
+    "KISAO_0000506": "genetic algorithm",
+    "KISAO_0000507": "genetic algorithm SR",
+    "KISAO_0000508": "evolutionary programming",
+    "KISAO_0000509": "evolutionary strategy",
+    "KISAO_0000510": "truncated Newton",
+    "KISAO_0000511": "steepest descent",
+    "KISAO_0000512": "praxis",
+    "KISAO_0000513": "NL2SOL",
+    "KISAO_0000514": "Nelder-Mead",
+    "KISAO_0000515": "Levenberg-Marquardt",
+    "KISAO_0000516": "Hooke&Jeeves",
+    "KISAO_0000517": "number of generations",
+    "KISAO_0000518": "evolutionary algorithm parameter",
+    "KISAO_0000519": "population size",
+    "KISAO_0000520": "evolutionary algorithm",
+    "KISAO_0000521": "simulated annealing parameter",
+    "KISAO_0000522": "start temperature",
+    "KISAO_0000523": "cooling factor",
+    "KISAO_0000524": "partitioned leaping method",
+    "KISAO_0000525": "stop condition",
+    "KISAO_0000526": "flux variability analysis",
+    "KISAO_0000527": "geometric flux balance analysis",
+    "KISAO_0000528": "parsimonious enzyme usage flux balance analysis (minimum sum of absolute fluxes)",
+    "KISAO_0000529": "parallelism",
+    "KISAO_0000531": "fraction of optimum",
+    "KISAO_0000532": "loopless",
+    "KISAO_0000533": "pFBA factor",
+    "KISAO_0000534": "reactions",
+    "KISAO_0000535": "VODE",
+    "KISAO_0000536": "ZVODE",
+    "KISAO_0000537": "explicit Runge-Kutta method of order 3(2)",
+    "KISAO_0000538": "safety factor on new step selection",
+    "KISAO_0000539": "minimum factor to change step size by",
+    "KISAO_0000540": "maximum factor to change step size by",
+    "KISAO_0000541": "beta parameter for stabilized step size control",
+    "KISAO_0000542": "correction step should use internally generated full Jacobian",
+    "KISAO_0000543": "stability limit detection flag",
+    "KISAO_0000544": "IDAS",
+    "KISAO_0000545": "include sensitivity variables in error control mechanism",
+    "KISAO_0000546": "convex optimization algorithm",
+    "KISAO_0000547": "linear programming",
+    "KISAO_0000548": "quadratic programming",
+    "KISAO_0000549": "non-linear programming",
+    "KISAO_0000550": "simplex method",
+    "KISAO_0000551": "primal-dual interior point method",
+    "KISAO_0000552": "optimization method",
+    "KISAO_0000553": "optimization solver",
+    "KISAO_0000554": "parsimonius flux balance analysis (minimum number of active fluxes)",
+    "KISAO_0000555": "absolute quadrature tolerance",
+    "KISAO_0000556": "relative quadrature tolerance",
+    "KISAO_0000557": "absolute steady-state tolerance",
+    "KISAO_0000558": "relative steady-state tolerance",
+    "KISAO_0000559": "initial step size",
+    "KISAO_0000560": "LSODA/LSODAR hybrid method",
+    "KISAO_0000561": "Pahle hybrid Gibson-Bruck Next Reaction method/Runge-Kutta method",
+    "KISAO_0000562": "Pahle hybrid Gibson-Bruck Next Reaction method/LSODA method",
+    "KISAO_0000563": "Pahle hybrid Gibson-Bruck Next Reaction method/RK-45 method",
+    "KISAO_0000564": "stochastic Runge-Kutta method",
+    "KISAO_0000565": "absolute tolerance for root finding",
+    "KISAO_0000566": "stochastic second order Runge-Kutta method",
+    "KISAO_0000567": "force physical correctness",
+    "KISAO_0000568": "NLEQ1",
+    "KISAO_0000569": "NLEQ2",
+    "KISAO_0000570": "auto reduce tolerances",
+    "KISAO_0000571": "absolute tolerance adjustment factor",
+    "KISAO_0000572": "level of superimposed noise",
+    "KISAO_0000573": "probabilistic logical model simulation method",
+    "KISAO_0000574": "species transition probabilities",
+    "KISAO_0000575": "hybrid tau-leaping method",
+    "KISAO_0000576": "quadratic MOMA",
+    "KISAO_0000577": "flux minimization weight",
+    "KISAO_0000578": "nested algorithm",
+    "KISAO_0000579": "linear MOMA",
+    "KISAO_0000580": "ROOM",
+    "KISAO_0000581": "BKMC",
+    "KISAO_0000582": "Spatiocyte method",
+    "KISAO_0000583": "minimum order",
+    "KISAO_0000584": "initial order",
+    "KISAO_0000585": "TOMS731",
+    "KISAO_0000586": "Gibson-Bruck next reaction algorithm with indexed priority queue",
+    "KISAO_0000587": "IMEX",
+    "KISAO_0000588": "flux sampling",
+    "KISAO_0000589": "ACB flux sampling method",
+    "KISAO_0000590": "ACHR flux sampling method",
+    "KISAO_0000591": "mdFBA",
+    "KISAO_0000592": "dynamic rFBA",
+    "KISAO_0000593": "MOMA",
+    "KISAO_0000594": "order",
+    "KISAO_0000595": "rFBA",
+    "KISAO_0000596": "srFBA",
+    "KISAO_0000597": "tolerance",
+    "KISAO_0000598": "hybrid Gibson - Milstein method",
+    "KISAO_0000599": "hybrid Gibson - Euler-Maruyama method",
+    "KISAO_0000600": "hybrid adaptive Gibson - Milstein method",
+    "KISAO_0000601": "number of trials",
+    "KISAO_0000602": "minimum species threshold for continuous approximation",
+    "KISAO_0000603": "minimum reaction rate for continuous approximation",
+    "KISAO_0000604": "MSR tolerance",
+    "KISAO_0000605": "SDE tolerance",
+    "KISAO_0000606": "hierarchical stochastic simulation algorithm",
+    "KISAO_0000607": "hierarchical Fehlberg method",
+    "KISAO_0000608": "hierarchical flux balance analysis",
+    "KISAO_0000609": "embedded Runge-Kutta Prince-Dormand (8,9) method",
+    "KISAO_0000610": "composite-rejection stochastic simulation algorithm",
+    "KISAO_0000611": "incremental stochastic simulation algorithm",
+    "KISAO_0000612": "implicit 4th order Runge-Kutta method at Gaussian points",
+    "KISAO_0000613": "stochastic simulation algorithm with normally-distributed next reaction times",
+    "KISAO_0000614": "implementation",
+    "KISAO_0000615": "fully-implicit regular grid finite volume method with a variable time step",
+    "KISAO_0000616": "semi-implicit regular grid finite volume method with a fixed time step",
+    "KISAO_0000617": "IDA-CVODE hybrid method",
+    "KISAO_0000618": "bunker",
+    "KISAO_0000619": "emc-sim",
+    "KISAO_0000620": "parsimonius flux balance analysis",
+    "KISAO_0000621": "stochastic simulation leaping method",
+    "KISAO_0000622": "flux balance method",
+    "KISAO_0000623": "flux balance problem",
+    "KISAO_0000624": "method for solving a system of linear equations",
+    "KISAO_0000625": "dense direct solver",
+    "KISAO_0000626": "band direct solver",
+    "KISAO_0000627": "diagonal approximate Jacobian solver",
+    "KISAO_0000628": "modelling and simulation algorithm parameter value",
+    "KISAO_0000629": "null",
+    "KISAO_0000630": "root-finding method",
+    "KISAO_0000631": "iterative root-finding method",
+    "KISAO_0000632": "functional iteration root-finding method",
+    "KISAO_0000633": "computational function",
+    "KISAO_0000634": "scaled property",
+    "KISAO_0000635": "unscaled property",
+    "KISAO_0000636": "primary property",
+    "KISAO_0000637": "derived property",
+    "KISAO_0000638": "level",
+    "KISAO_0000639": "flux",
+    "KISAO_0000640": "lower bound",
+    "KISAO_0000641": "bound",
+    "KISAO_0000642": "minimum flux",
+    "KISAO_0000643": "upper bound",
+    "KISAO_0000644": "maximum flux",
+    "KISAO_0000645": "objective value",
+    "KISAO_0000646": "propensity",
+    "KISAO_0000647": "derivative",
+    "KISAO_0000648": "step",
+    "KISAO_0000649": "shadow price",
+    "KISAO_0000650": "sensitivity",
+    "KISAO_0000651": "reduced costs",
+    "KISAO_0000652": "concentration rate",
+    "KISAO_0000653": "particle number rate",
+    "KISAO_0000654": "amount rate",
+    "KISAO_0000655": "rate",
+    "KISAO_0000656": "use adaptive time steps",
+    "KISAO_0000657": "sequential logical simulation method",
+    "KISAO_0000658": "logical model analysis method",
+    "KISAO_0000659": "Naldi MDD logical model stable state search method",
+    "KISAO_0000660": "logical model stable state search method",
+    "KISAO_0000661": "logical model trap space identification method",
+    "KISAO_0000662": "Klarner ASP logical model trap space identification method",
+    "KISAO_0000663": "BDD logical model trap space identification method",
+    "KISAO_0000664": "Second order backward implicit product Euler scheme",
+    "KISAO_0000665": "maximum number of iterations for root finding",
+    "KISAO_0000666": "Jacobian epsilon",
+    "KISAO_0000667": "memory size",
+    "KISAO_0000668": "Numerical Recipes in C 'stiff' Rosenbrock method",
+    "KISAO_0000669": "Resource Balance Analysis",
+    "KISAO_0000670": "use multiple steps",
+    "KISAO_0000671": "use stiff method",
+    "KISAO_0000672": "Numerical Recipes in C 'quality-controlled Runge-Kutta' method",
+    "KISAO_0000673": "skip reactions that produce negative species amounts",
+    "KISAO_0000674": "presimulate",
+    "KISAO_0000675": "Broyden method",
+    "KISAO_0000676": "degree of linearity",
+    "KISAO_0000677": "maximum number of steps for presimulation",
+    "KISAO_0000678": "maximum number of steps for approximation",
+    "KISAO_0000679": "maximum time for approximation",
+    "KISAO_0000680": "duration",
+    "KISAO_0000681": "maximum time",
+    "KISAO_0000682": "allow approximation",
+    "KISAO_0000683": "relative tolerance for approximation",
+    "KISAO_0000684": "number of steps per output",
+    "KISAO_0000800": "systems property",
+    "KISAO_0000801": "concentration control coefficient matrix (unscaled)",
+    "KISAO_0000802": "control coefficient (scaled)",
+    "KISAO_0000803": "control coefficient (unscaled)",
+    "KISAO_0000804": "elasticity matrix (unscaled)",
+    "KISAO_0000805": "elasticity coefficient (unscaled)",
+    "KISAO_0000806": "elasticity matrix (scaled)",
+    "KISAO_0000807": "elasticity coefficient (scaled)",
+    "KISAO_0000808": "reduced stoichiometry matrix",
+    "KISAO_0000809": "reduced Jacobian matrix",
+    "KISAO_0000810": "reduced eigenvalue matrix",
+    "KISAO_0000811": "stoichiometry matrix",
+    "KISAO_0000812": "Jacobian matrix",
+    "KISAO_0000813": "Eigenvalue matrix",
+    "KISAO_0000814": "flux control coefficient matrix (unscaled)",
+    "KISAO_0000815": "flux control coefficient matrix (scaled)",
+    "KISAO_0000816": "link matrix",
+    "KISAO_0000817": "kernel matrix",
+    "KISAO_0000818": "L0 matrix",
+    "KISAO_0000819": "Nr matrix",
+    "KISAO_0000820": "model and simulation property characteristic",
+    "KISAO_0000821": "intensive property",
+    "KISAO_0000822": "extensive property",
+    "KISAO_0000824": "aggregation function",
+    "KISAO_0000825": "mean",
+    "KISAO_0000826": "standard deviation",
+    "KISAO_0000827": "standard error",
+    "KISAO_0000828": "maximum",
+    "KISAO_0000829": "minimum",
+    "KISAO_0000831": "model and simulation property",
+    "KISAO_0000832": "time",
+    "KISAO_0000834": "rate of change",
+    "KISAO_0000835": "concentration control coefficient matrix (scaled)",
+    "KISAO_0000836": "amount",
+    "KISAO_0000837": "particle number",
+    "KISAO_0000838": "concentration",
+    "KISAO_0000839": "temperature",
+}
 
 
 class KISAO(str, Enum):
@@ -1794,7 +2299,7 @@ class KISAO(str, Enum):
     KISAO_0000667 = "KISAO_0000667"
     MEMORY_SIZE = "KISAO_0000667"
 
-    # Numerical Recipes in C "stiff" Rosenbrock method
+    # Numerical Recipes in C 'stiff' Rosenbrock method
     KISAO_0000668 = "KISAO_0000668"
     NUMERICAL_RECIPES_IN_C__STIFF__ROSENBROCK_METHOD = "KISAO_0000668"
 
@@ -1810,7 +2315,7 @@ class KISAO(str, Enum):
     KISAO_0000671 = "KISAO_0000671"
     USE_STIFF_METHOD = "KISAO_0000671"
 
-    # Numerical Recipes in C "quality-controlled Runge-Kutta" method
+    # Numerical Recipes in C 'quality-controlled Runge-Kutta' method
     KISAO_0000672 = "KISAO_0000672"
     NUMERICAL_RECIPES_IN_C__QUALITY_CONTROLLED_RUNGE_KUTTA__METHOD = "KISAO_0000672"
 
@@ -2010,7 +2515,34 @@ class KISAO(str, Enum):
     KISAO_0000839 = "KISAO_0000839"
     TEMPERATURE = "KISAO_0000839"
 
+    @staticmethod
+    def get_name(kisao: "KISAO") -> Optional[str]:
+        """Get name for term.
+
+        :returns: None if term does not exist in ontology.
+        """
+        return _terms.get(kisao.value, None)
+
+    @classmethod
+    def validate(cls, kisao: "KISAOType") -> "KISAO":
+        """Validate and normalize kisao."""
+        term: "KISAO"
+        if isinstance(kisao, str):
+            if not kisao.startswith("KISAO"):
+                raise ValueError(kisao + " is not a KISAO id.")
+            if kisao.startswith("KISAO:"):
+                kisao = kisao.replace(":", "_")
+            term = getattr(cls, kisao)
+
+        elif isinstance(kisao, "KISAO"):
+            term = kisao
+        else:
+            raise ValueError
+
+        return term
+
 
 __all__ = [
     "KISAO",
+    "KISAOType",
 ]
